import importlib.util
from pathlib import Path
import sys
from types import ModuleType
import unittest

PLUGIN_ROOT = Path(__file__).resolve().parents[1]
ENTRYPOINT_PATH = PLUGIN_ROOT / "entrypoint.py"


def load_entrypoint_module():
    fake_fender = ModuleType("ocyan.core.fender")
    fake_fender.config = ModuleType("config")
    fake_fender.config.is_webshop = False

    fake_plugins = ModuleType("ocyan.core.plugins")

    class FakeOcyanPluginConfig:
        pass

    fake_plugins.OcyanPluginConfig = FakeOcyanPluginConfig

    fake_utils = ModuleType("ocyan.core.utils")
    fake_utils.merge_dicts = lambda left, right, overwrite=False: {**left, **right}

    sys.modules["ocyan.core.fender"] = fake_fender
    sys.modules["ocyan.core.plugins"] = fake_plugins
    sys.modules["ocyan.core.utils"] = fake_utils

    spec = importlib.util.spec_from_file_location(
        "carbasa_entrypoint_for_tests", ENTRYPOINT_PATH
    )
    module = importlib.util.module_from_spec(spec)
    assert spec and spec.loader
    spec.loader.exec_module(module)
    return module


class CarbasaSmokeTests(unittest.TestCase):
    def test_entrypoint_is_available(self):
        entrypoint = load_entrypoint_module()
        CarbasaConfig = entrypoint.CarbasaConfig
        self.assertEqual(CarbasaConfig.__name__, "CarbasaConfig")

    def test_tabs_template_uses_unique_ids(self):
        template = (
            PLUGIN_ROOT / "templates" / "carbasa" / "blocks" / "tabsblock.html"
        ).read_text()
        self.assertNotIn('id="pills-home-tab"', template)
        self.assertIn('aria-controls="{{ tab_id }}"', template)
        self.assertIn('aria-labelledby="{{ tab_button_id }}"', template)

    def test_accordion_template_uses_button_control(self):
        template = (
            PLUGIN_ROOT
            / "templates"
            / "coyote"
            / "blocks"
            / "content"
            / "accordion.html"
        ).read_text()
        self.assertIn("<button", template)
        self.assertIn('class="accordion-button', template)
        self.assertNotIn('<p class="accordion-header', template)

    def test_dropdown_template_uses_button_toggle(self):
        template = (
            PLUGIN_ROOT / "templates" / "partials" / "dropdown.html"
        ).read_text()
        self.assertIn("<button", template)
        self.assertNotIn('<a class="nav-link toggle"', template)

    def test_newsletter_block_has_no_inline_style(self):
        template = (
            PLUGIN_ROOT
            / "templates"
            / "roadrunner_bs4"
            / "blocks"
            / "newsletter_block.html"
        ).read_text()
        self.assertNotIn("<style", template)

    def test_layout_still_loads_runtime_carbasa_javascript(self):
        template = (PLUGIN_ROOT / "templates" / "layout.html").read_text()
        self.assertIn("carbasa/js/carbasa.js", template)

    def test_readme_documents_runtime_javascript_path(self):
        readme = (PLUGIN_ROOT.parents[2] / "README.md").read_text()
        self.assertIn("static/carbasa/js/carbasa.js", readme)

    def test_readme_documents_legacy_config_typo_key(self):
        readme = (PLUGIN_ROOT.parents[2] / "README.md").read_text()
        self.assertIn("same_hight_product_image", readme)


if __name__ == "__main__":
    unittest.main()



# -*- coding: utf-8 -*-
from ocyan.core.fender import config
from ocyan.core.plugins import OcyanPluginConfig
from ocyan.core.utils import merge_dicts


class CarbasaConfig(OcyanPluginConfig):
    def contribute_to_installed_apps(self, installed_apps):
        installed_apps.front.append("ocyan.plugin.carbasa")
        installed_apps.front.register_extension("ocyan.plugin.carbasa", "oxyan.themes")
        installed_apps.wagtail.register_extension(
            "ocyan.plugin.carbasa", "ocyan.plugin.coyote"
        )

        if config.is_webshop:  # enable the webshop extension
            installed_apps.front.register_extension(
                "ocyan.plugin.carbasa.webshop", "oxyan.themes"
            )
            installed_apps.front.register_extension(
                "ocyan.plugin.carbasa.webshop", "ocyan.plugin.carbasa"
            )
            installed_apps.front.register_extension(
                "ocyan.plugin.carbasa.webshop", "ocyan.plugin.coyote.oxyan_extension"
            )
            installed_apps.wagtail.register_extension(
                "ocyan.plugin.carbasa.webshop",
                "ocyan.plugin.wagtail_oscar_integration.wagtail_oscar_integration_coyote_extension",
            )
        else:
            installed_apps.front.register_extension(
                "ocyan.plugin.carbasa", "ocyan.plugin.barebone"
            )

        return installed_apps

    def contribute_to_settings(self, settings):
        return merge_dicts(
            settings,
            {
                "OXYAN_HEADER_OPTIONS": [
                    ("basic", "Basic Header"),
                    ("big", "Big Header"),
                    ("mega", "Mega Header"),
                ],
            },
            overwrite=True,
        )



# -*- coding: utf-8 -*-
from setuptools import find_packages, setup

install_requires: list = ["ocyan.core", "ocyan.plugin.coyote", "oxyan.themes"]

extras_require: dict = {
    "test": [
        "empty_testproject",
        "ocyan.plugin.testing",
        "pylint-django",
        "ruff",
        "vdt.versionplugin.wheel",
        "coverage",
        "ocyan.plugin.wagtail_oscar_integration",
    ]
}

PACKAGE_CLASSIFIERS = [
    "License :: Other/Proprietary License",
    "Framework :: Ocyan",
    "Environment :: Plugins",
]

setup(
    name="ocyan.plugin.carbasa",
    version="0.1.3",
    url="https://git.mandelblog.com/mandel-plugins/ocyan.plugin.carbasa",
    author="Mandel",
    author_email="info@mandelblog.com",
    description=(
        "An extension of coyote plugin to easily update styling of webshop,"
        " by updating settings in wagtail admin."
    ),
    packages=find_packages(),
    include_package_data=True,
    python_requires=">=3.6",
    install_requires=install_requires,
    classifiers=PACKAGE_CLASSIFIERS,
    extras_require=extras_require,
)



import uuid

from django.utils.translation import gettext as _

from wagtail import blocks
from wagtail.images.blocks import ImageChooserBlock

from ocyan.plugin.coyote.blocks.partials import CoyoteButtonBlock, CoyoteStructBlock
from ocyan.plugin.coyote.custom_blocks import VisualChoiceBlock


class CoyoteContent(blocks.StructBlock):
    layout = VisualChoiceBlock(
        choices=[
            ("layout1", "carbasa/layouts/content_layout_1.png"),
            ("layout2", "carbasa/layouts/content_layout_2.png"),
        ],
        default="layout1",
        label=_("Layout"),
    )
    image = ImageChooserBlock(label=_("Image"))
    secondairy_image = ImageChooserBlock(label=_("Image"), required=False)
    tertiary_image = ImageChooserBlock(label=_("Image"), required=False)
    body = blocks.RichTextBlock(
        label=_("Body"),
        required=True,
        features=["h1", "h2", "h3", "h4", "bold", "italic", "link"],
    )
    buttons = blocks.ListBlock(
        CoyoteButtonBlock(), label=_("Buttons"), required=False, collapsed=True
    )
    go_to_text = blocks.CharBlock(label=_("Cta text"), required="False")
    go_to_link = blocks.CharBlock(label=_("Cta link"), required="False")

    class Meta:
        label = _("Text")
        icon = "italic"
        template = "coyote/blocks/header/content.html"


class BootstrapTabBlock(blocks.StructBlock):
    header = blocks.CharBlock(label=_("Title"))
    body = blocks.RichTextBlock(label=_("Body"))
    image = ImageChooserBlock(label=_("Image"))
    button = CoyoteButtonBlock(required=False, label=_("Button"))


class CoyoteTabsBlock(CoyoteStructBlock):
    header = blocks.CharBlock(label=_("Title"), required=False)
    body = blocks.RichTextBlock(label=_("Body"), required=False)
    tabs = blocks.ListBlock(
        BootstrapTabBlock(), label=_("Tabbed content"), required=False, collapsed=True
    )

    def get_uuid(self):
        return uuid.uuid4()

    class Meta:
        icon = "table"
        template = "carbasa/blocks/tabsblock.html"


class CoyoteCallToAction(blocks.StructBlock):
    header = blocks.CharBlock(required=False, label=_("Title"))
    body = blocks.RichTextBlock(required=False, label=_("Body"))
    button = CoyoteButtonBlock(required=False, label=_("Button"))

    class Meta:
        template = "carbasa/blocks/calltoaction.html"
        icon = "pick"


class CarbasaQuoteBlock(blocks.StructBlock):
    stars = blocks.CharBlock(required=False, label=_("Stars"))
    image = ImageChooserBlock(required=False, label=_("Image"))
    name = blocks.CharBlock(required=False, label=_("Full name"))
    function = blocks.CharBlock(required=False, label=_("Function"))
    header = blocks.TextBlock(required=False, label=_("Header"))
    quote = blocks.TextBlock(required=False, label="Quote")


class CoyoteQuotesBlock(CoyoteStructBlock):
    image = ImageChooserBlock(required=False, label="Afbeelding")
    quotes = blocks.ListBlock(
        CarbasaQuoteBlock(), required=True, collapsed=True, label=_("Quotes")
    )

    class Meta:
        template = "coyote/blocks/content/quotesblock.html"
        icon = "openquote"


class CoyotePersonListBlock(CoyoteStructBlock):
    b1_tagline = blocks.CharBlock(required=False, label="Tagline¹")
    b1_header = blocks.CharBlock(required=False, label="Header¹")
    b1_cta = blocks.CharBlock(required=False, label="CallToAction¹", default="Shop now")
    b1_link = blocks.URLBlock(required=False, label="Link¹", default="Shop now")
    b1_image = ImageChooserBlock(required=False, label="Image¹")
    b2_tagline = blocks.CharBlock(required=False, label="Tagline²")
    b2_header = blocks.CharBlock(required=False, label="Header²")
    b2_cta = blocks.CharBlock(required=False, label="CallToAction²", default="Shop now")
    b2_link = blocks.URLBlock(required=False, label="Link²", default="Shop now")
    b2_image = ImageChooserBlock(required=False, label="Image²")

    class Meta:
        label = "koeien"
        template = "coyote/blocks/content/banner_block.html"



# -*- coding: utf-8 -*-
default_app_config = "ocyan.plugin.carbasa.apps.OcyanPluginCarbasaAppConfig"

__all__ = ["CarbasaConfig"]


def __getattr__(name):
    if name == "CarbasaConfig":
        from .entrypoint import CarbasaConfig

        return CarbasaConfig
    raise AttributeError(f"module {__name__!r} has no attribute {name!r}")



from django.utils.translation import gettext as _

from wagtail import blocks
from wagtail.images.blocks import ImageChooserBlock

from ocyan.main.loading import get_baseclass
from ocyan.plugin.coyote.blocks.partials import CoyoteButtonBlock, CoyoteStructBlock
from ocyan.plugin.coyote.custom_blocks import LinkChooserBlock
from ocyan.plugin.wagtail_oscar_integration.blocks import (
    CategoryChooserBlock,
    ProductChooserBlock,
)

BaseHomePageContentStreamBlock = get_baseclass(
    "coyote.stream_blocks",
    "HomePageContentStreamBlock",
    "ocyan.plugin.carbasa.webshop",
)


class CoyoteProductsBlock(CoyoteStructBlock):
    tagline = blocks.CharBlock(required=False, label=_("Tagline"))
    header = blocks.CharBlock(required=False, label=_("Header"))
    banner_link = blocks.URLBlock(required=False)
    buttons = blocks.ListBlock(
        CoyoteButtonBlock(),
        label=_("Buttons"),
        required=False,
        collapsed=True,
        default=[],
    )
    products = blocks.ListBlock(
        ProductChooserBlock(), required=False, label="Products", default=[]
    )

    class Meta:
        template = "coyote/blocks/content/productsblock.html"


class CarbasaCategorychooser(blocks.StructBlock):
    category = CategoryChooserBlock(required=False)
    image = ImageChooserBlock(
        required=False, help_text=_("default is set to category image")
    )
    label = blocks.CharBlock(
        required=False, help_text=_("Default is set to category label")
    )
    page_link = LinkChooserBlock(
        label=_("Link"),
        required=False,
        help_text=_("This will overwrite the category link"),
    )


class CoyoteCategoryBlock(CoyoteStructBlock):
    tagline = blocks.CharBlock(required=False, label=_("Tagline"))
    header = blocks.CharBlock(required=False, label=_("Header"))
    categories = blocks.ListBlock(
        CarbasaCategorychooser(), required=False, label=_("Categories")
    )

    class Meta:
        template = "coyote/blocks/content/categoryblock.html"


class HomePageContentStreamBlock(BaseHomePageContentStreamBlock):
    Products = CoyoteProductsBlock(icon="tag")
    Category = CoyoteCategoryBlock(icon="tag")
